==> mingw-w64-clang-aarch64-qt6-static-6.7.0-1-any.pkg.tar.zst: clangarm64/qt6-static/lib/cmake/Qt6QuickControls2BasicStyleImpl/Qt6QuickControls2BasicStyleImplTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::QuickControls2BasicStyleImpl" for configuration "Release"
set_property(TARGET Qt6::QuickControls2BasicStyleImpl APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::QuickControls2BasicStyleImpl PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libQt6QuickControls2BasicStyleImpl.a"
  )

list(APPEND _cmake_import_check_targets Qt6::QuickControls2BasicStyleImpl )
list(APPEND _cmake_import_check_files_for_Qt6::QuickControls2BasicStyleImpl "${_IMPORT_PREFIX}/lib/libQt6QuickControls2BasicStyleImpl.a" )

# Import target "Qt6::QuickControls2BasicStyleImpl_resources_1" for configuration "Release"
set_property(TARGET Qt6::QuickControls2BasicStyleImpl_resources_1 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::QuickControls2BasicStyleImpl_resources_1 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/Controls/Basic/impl/objects-Release/QuickControls2BasicStyleImpl_resources_1/.rcc/qrc_qmake_QtQuick_Controls_Basic_impl_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::QuickControls2BasicStyleImpl_resources_1 )
list(APPEND _cmake_import_check_files_for_Qt6::QuickControls2BasicStyleImpl_resources_1 "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/Controls/Basic/impl/objects-Release/QuickControls2BasicStyleImpl_resources_1/.rcc/qrc_qmake_QtQuick_Controls_Basic_impl_init.cpp.obj" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> mingw-w64-clang-aarch64-qt6-static-6.8.0-3-any.pkg.tar.zst: clangarm64/qt6-static/lib/cmake/Qt6QuickControls2BasicStyleImpl/Qt6QuickControls2BasicStyleImplTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::QuickControls2BasicStyleImpl" for configuration "Release"
set_property(TARGET Qt6::QuickControls2BasicStyleImpl APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::QuickControls2BasicStyleImpl PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libQt6QuickControls2BasicStyleImpl.a"
  )

list(APPEND _cmake_import_check_targets Qt6::QuickControls2BasicStyleImpl )
list(APPEND _cmake_import_check_files_for_Qt6::QuickControls2BasicStyleImpl "${_IMPORT_PREFIX}/lib/libQt6QuickControls2BasicStyleImpl.a" )

# Import target "Qt6::QuickControls2BasicStyleImpl_resources_1" for configuration "Release"
set_property(TARGET Qt6::QuickControls2BasicStyleImpl_resources_1 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::QuickControls2BasicStyleImpl_resources_1 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/Controls/Basic/impl/objects-Release/QuickControls2BasicStyleImpl_resources_1/.qt/rcc/qrc_qmake_QtQuick_Controls_Basic_impl_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::QuickControls2BasicStyleImpl_resources_1 )
list(APPEND _cmake_import_check_files_for_Qt6::QuickControls2BasicStyleImpl_resources_1 "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/Controls/Basic/impl/objects-Release/QuickControls2BasicStyleImpl_resources_1/.qt/rcc/qrc_qmake_QtQuick_Controls_Basic_impl_init.cpp.obj" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
